# gitlab-cloud-connector (Ruby)

Ruby gem containing shared code for Cloud Connector token issuers (GitLab, CustomersDot).

## Usage

We expect Bundler is used to manage dependencies. To add the dependency, add it to `Gemfile`:

```Gemfile
gem "gitlab-cloud-connector", "~> 0.1.1", require: 'cloud_connector'
```

## Usage

### Data Storage

Cloud Connector uses YAML files stored in the project's `/config` directory. The data is organized by model type:

```yaml
# config/backend_services/ai_gateway.yml
name: ai_gateway
description: "AI Gateway"
jwt_aud: gitlab-ai-gateway

# config/add_ons/duo_pro.yml
name: duo_pro
description: "Duo Pro"

# config/unit_primitives/duo_chat.yml
name: duo_chat
description: "Duo Chat"
backend_services:
  - ai_gateway
add_ons:
  - duo_pro
  - duo_enterprise
```

### Working with DataModels

`DataModels` are the core data structures in the Cloud Connector. Each model inherits from `DataModel::Base`. The data is loaded from YAML files into memory at runtime, making it efficient for read operations and relationship traversal.

```ruby
require 'cloud_connector'

# Find unit primitive by name
# Note:  value should be a symbol (e.g., `:duo_chat` instead of `'duo_chat'`).
duo_chat = Gitlab::CloudConnector::DataModels::UnitPrimitive.find_by_name(:duo_chat)
duo_chat.description
duo_chat.cut_off_date

# access associations
duo_chat.add_ons
duo_chat.license_types
duo_chat.backend_services

# read duo_chat audiences
duo_chat.backend_services.map(&:jwt_aud)
```

## Release Process

See [Release Process](../../README.md#release-process)

Once the new gem version is visible on [RubyGems.org](https://rubygems.org/gems/gitlab-cloud-connector),
it is recommended to update [GitLab's `Gemfile`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/Gemfile)
and [Customers Dot's `Gemfile`](https://gitlab.com/gitlab-org/customers-gitlab-com/-/blob/main/Gemfile) to bump the `gitlab-cloud-connector`
Ruby gem to the new version also. See [Usage](#usage) for how to do this.
