# frozen_string_literal: true

require_relative 'associations'
require_relative 'data_loader'

module Gitlab
  module CloudConnector
    module DataModel
      class Base
        include Associations
        extend Enumerable

        class << self
          def model_name
            name&.demodulize
          end

          def each(&block)
            all.each(&block)
          end

          def find_by_name(name)
            all.find { |record| record.name.to_sym == name }
          end

          def all
            @all ||= data_loader.load!
          end

          private

          def data_loader
            @data_loader ||= DataLoader.new(self)
          end
        end

        def initialize(**opts)
          opts.each do |key, value|
            instance_variable_set(:"@#{key}", value)
          end
        end

        def [](name)
          instance_variable_get(:"@#{name}")
        end
      end
    end
  end
end
