# frozen_string_literal: true

require 'yaml'

module Gitlab
  module CloudConnector
    module DataModel
      class DataLoader
        def initialize(model_class)
          @model_class = model_class
        end

        def load!
          Dir.glob(data_files_path).map { |file| load_model_from_file(file) }
        end

        private

        attr_reader :model_class

        def data_files_path
          File.join(CloudConnector::Configuration.config_dir, model_class.model_name.tableize, '*.yml')
        end

        def load_model_from_file(file_path)
          data = YAML.safe_load(
            File.read(file_path),
            permitted_classes: [Time],
            symbolize_names: true
          ).deep_symbolize_keys!

          model_class.new(**data)
        rescue StandardError => e
          raise "Error loading file #{file_path}: #{e.message}"
        end
      end
    end
  end
end
